aboutsummaryrefslogtreecommitdiffstats
path: root/include/llvm/CodeGen/FastISel.h
diff options
context:
space:
mode:
authorEvan Cheng <evan.cheng@apple.com>2009-01-22 09:10:11 +0000
committerEvan Cheng <evan.cheng@apple.com>2009-01-22 09:10:11 +0000
commit536ab130ec95cbb7bf30530251dafa7dfecc8471 (patch)
treec971d4e06869171104e9756ab2bdab1ab0a25ed6 /include/llvm/CodeGen/FastISel.h
parente70909b8c94b18ae5fcfe8010251d2527704d58b (diff)
downloadexternal_llvm-536ab130ec95cbb7bf30530251dafa7dfecc8471.zip
external_llvm-536ab130ec95cbb7bf30530251dafa7dfecc8471.tar.gz
external_llvm-536ab130ec95cbb7bf30530251dafa7dfecc8471.tar.bz2
Eliminate a couple of fields from TargetRegisterClass: SubRegClasses and SuperRegClasses. These are not necessary. Also eliminate getSubRegisterRegClass and getSuperRegisterRegClass. These are slow and their results can change if register file names change. Just use TargetLowering::getRegClassFor() to get the right TargetRegisterClass instead.
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@62762 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/CodeGen/FastISel.h')
-rw-r--r--include/llvm/CodeGen/FastISel.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/include/llvm/CodeGen/FastISel.h b/include/llvm/CodeGen/FastISel.h
index 0b8d67b..8c04848 100644
--- a/include/llvm/CodeGen/FastISel.h
+++ b/include/llvm/CodeGen/FastISel.h
@@ -259,8 +259,9 @@ protected:
uint64_t Imm);
/// FastEmitInst_extractsubreg - Emit a MachineInstr for an extract_subreg
- /// from a specified index of a superregister.
- unsigned FastEmitInst_extractsubreg(unsigned Op0, uint32_t Idx);
+ /// from a specified index of a superregister to a specified type.
+ unsigned FastEmitInst_extractsubreg(MVT::SimpleValueType RetVT,
+ unsigned Op0, uint32_t Idx);
/// FastEmitBranch - Emit an unconditional branch to the given block,
/// unless it is the immediate (fall-through) successor, and update